@@ -34,17 +34,17 @@ def retry(retries: int = 2, delay: int = 0):
                     next_message = "Will try again" if i < retries else "Will not try again"
                     _LOGGER.warning("Got exception: %s. %s", str(_e), next_message)
                     last_warning_exception = _e
-                    pass
-                if delay > 0:
-                    await asyncio.sleep(delay)
-            else:
-                _LOGGER.critical("Retry limit (%d) exceeded for %s(%s, %s)", retries, f.__name__, args, kwargs)
-                if _LOGGER.level > logging.INFO and last_info_exception is not None:
-                    _LOGGER.critical(f"Last exception was {last_info_exception}")
-                elif _LOGGER.level > logging.WARNING and last_warning_exception is not None:
-                    _LOGGER.critical(f"Last exception was {last_warning_exception}")
+                    if delay > 0:
+                        await asyncio.sleep(delay)
+
+            _LOGGER.critical("Retry limit (%d) exceeded for %s(%s, %s)", retries, f.__name__, args, kwargs)
+            if _LOGGER.level > logging.INFO and last_info_exception is not None:
+                _LOGGER.critical(f"Last exception was {last_info_exception}")
+            elif _LOGGER.level > logging.WARNING and last_warning_exception is not None:
+                _LOGGER.critical(f"Last exception was {last_warning_exception}")
+
+            raise MaxTriesExceededError
 
-                raise MaxTriesExceededError
         return wrapper
     return decor
 
@@ -82,6 +82,7 @@ class Tion:
     def __init__(self, mac: str | BLEDevice):
         self._mac = mac
         self._btle: BleakClient = BleakClient(mac)
+        self._next_btle_device: BleakClient | None = None
         self._delegation = TionDelegation()
         self._fan_speed = 0
         self._model: str = self.__class__.__name__
@@ -291,8 +292,8 @@ class Tion:
     @retry(retries=1, delay=2)
     async def _try_connect(self) -> bool:
         """Tries to connect with retries"""
-
-        return await self._btle.connect(timeout=5.0)
+        self.set_new_btle_device()
+        return await self._btle.connect()
 
     @final
     async def _connect(self, need_notifications: bool = True):
@@ -315,6 +316,8 @@ class Tion:
         _LOGGER.debug(f"Disconnecting. {self.connection_status=}.")
         if self.connection_status != "disc":
             await self._btle.disconnect()
+            self.set_new_btle_device()
+
         _LOGGER.debug(f"_disconnect done. {self.connection_status=}")
 
     @final
@@ -570,4 +573,12 @@ class Tion:
         if new_device is None:
             _LOGGER.info(f"Skipping update due to {new_device= }!")
             return
-        self._btle = BleakClient(new_device)
+        self._next_btle_device = new_device
+
+    @final
+    def set_new_btle_device(self):
+        if self._next_btle_device is not None:
+            async with self._semaphore:
+                _LOGGER.debug("Updating _btle instance")
+                self._btle = BleakClient(self._next_btle_device)
+                self._next_btle_device = None
